import codepipeline = require('@aws-cdk/aws-codepipeline-api');
import cdk = require('@aws-cdk/cdk');
import { RepositoryRef } from './repository';
/**
 * Construction properties of the {@link PipelineSource CodeCommit source CodePipeline Action}.
 */
export interface PipelineSourceProps extends codepipeline.CommonActionProps {
    /**
     * The name of the source's output artifact.
     * Output artifacts are used by CodePipeline as inputs into other actions.
     */
    artifactName: string;
    /**
     * The CodeCommit repository.
     */
    repository: RepositoryRef;
    /**
     * @default 'master'
     */
    branch?: string;
    /**
     * Whether or not AWS CodePipeline should poll for source changes.
     *
     * @default true
     */
    pollForSourceChanges?: boolean;
}
/**
 * CodePipeline Source that is provided by an AWS CodeCommit repository.
 */
export declare class PipelineSource extends codepipeline.SourceAction {
    constructor(parent: cdk.Construct, name: string, props: PipelineSourceProps);
}
