import cdk = require('@aws-cdk/cdk');
import { LogGroup } from './log-group';
/**
 * Properties for a new LogStream
 */
export interface LogStreamProps {
    /**
     * The log group to create a log stream for.
     */
    logGroup: LogGroup;
    /**
     * The name of the log stream to create.
     *
     * The name must be unique within the log group.
     *
     * @default Automatically generated
     */
    logStreamName?: string;
    /**
     * Retain the log stream if the stack or containing construct ceases to exist
     *
     * Normally you want to retain the log stream so you can diagnose issues
     * from logs even after a deployment that no longer includes the log stream.
     *
     * The date-based retention policy of your log group will age out the logs
     * after a certain time.
     *
     * @default true
     */
    retainLogStream?: boolean;
}
/**
 * A new Log Stream in a Log Group
 */
export declare class LogStream extends cdk.Construct {
    /**
     * The name of this log stream
     */
    readonly logStreamName: LogStreamName;
    constructor(parent: cdk.Construct, id: string, props: LogStreamProps);
}
/**
 * The name of a log stream
 */
export declare class LogStreamName extends cdk.Token {
}
