import cdk = require('@aws-cdk/cdk');
export declare namespace cloudformation {
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codecommit-repository.html
     */
    interface RepositoryResourceProps {
        /**
         * ``AWS::CodeCommit::Repository.RepositoryName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codecommit-repository.html#cfn-codecommit-repository-repositoryname
         */
        repositoryName: string | cdk.Token;
        /**
         * ``AWS::CodeCommit::Repository.RepositoryDescription``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codecommit-repository.html#cfn-codecommit-repository-repositorydescription
         */
        repositoryDescription?: string | cdk.Token;
        /**
         * ``AWS::CodeCommit::Repository.Triggers``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codecommit-repository.html#cfn-codecommit-repository-triggers
         */
        triggers?: Array<RepositoryResource.RepositoryTriggerProperty | cdk.Token> | cdk.Token;
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codecommit-repository.html
     */
    class RepositoryResource extends cdk.Resource {
        /**
         * The CloudFormation resource type name for this resource class.
         */
        static readonly resourceTypeName: string;
        /**
         * @cloudformation_attribute Arn
         */
        readonly repositoryArn: RepositoryArn;
        /**
         * @cloudformation_attribute CloneUrlHttp
         */
        readonly repositoryCloneUrlHttp: RepositoryCloneUrlHttp;
        /**
         * @cloudformation_attribute CloneUrlSsh
         */
        readonly repositoryCloneUrlSsh: RepositoryCloneUrlSsh;
        /**
         * @cloudformation_attribute Name
         */
        readonly repositoryName: RepositoryName;
        /**
         * Creates a new ``AWS::CodeCommit::Repository``.
         *
         * @param parent     the ``cdk.Construct`` this ``RepositoryResource`` is a part of
         * @param name       the name of the resource in the ``cdk.Construct`` tree
         * @param properties the properties of this ``RepositoryResource``
         */
        constructor(parent: cdk.Construct, name: string, properties: RepositoryResourceProps);
        protected renderProperties(): {
            [key: string]: any;
        };
    }
    namespace RepositoryResource {
        /**
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codecommit-repository-repositorytrigger.html
         */
        interface RepositoryTriggerProperty {
            /**
             * ``RepositoryResource.RepositoryTriggerProperty.Branches``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codecommit-repository-repositorytrigger.html#cfn-codecommit-repository-repositorytrigger-branches
             */
            branches?: Array<string | cdk.Token> | cdk.Token;
            /**
             * ``RepositoryResource.RepositoryTriggerProperty.CustomData``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codecommit-repository-repositorytrigger.html#cfn-codecommit-repository-repositorytrigger-customdata
             */
            customData?: string | cdk.Token;
            /**
             * ``RepositoryResource.RepositoryTriggerProperty.DestinationArn``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codecommit-repository-repositorytrigger.html#cfn-codecommit-repository-repositorytrigger-destinationarn
             */
            destinationArn?: string | cdk.Token;
            /**
             * ``RepositoryResource.RepositoryTriggerProperty.Events``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codecommit-repository-repositorytrigger.html#cfn-codecommit-repository-repositorytrigger-events
             */
            events?: Array<string | cdk.Token> | cdk.Token;
            /**
             * ``RepositoryResource.RepositoryTriggerProperty.Name``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codecommit-repository-repositorytrigger.html#cfn-codecommit-repository-repositorytrigger-name
             */
            name?: string | cdk.Token;
        }
    }
}
export declare class RepositoryArn extends cdk.Arn {
}
export declare class RepositoryCloneUrlHttp extends cdk.Token {
}
export declare class RepositoryCloneUrlSsh extends cdk.Token {
}
export declare class RepositoryName extends cdk.Token {
}
