export interface LambdaRuntimeProps {
    /**
     * Whether the ``ZipFile`` (aka inline code) property can be used with this runtime.
     * @default false
     */
    readonly supportsInlineCode?: boolean;
}
/**
 * Lambda function runtime environment.
 */
export declare class Runtime implements InlinableRuntime, InlinableJavaScriptRuntime {
    static readonly NodeJS: InlinableJavaScriptRuntime;
    static readonly NodeJS43: InlinableJavaScriptRuntime;
    static readonly NodeJS43Edge: Runtime;
    static readonly NodeJS610: InlinableJavaScriptRuntime;
    static readonly NodeJS810: Runtime;
    static readonly Java8: Runtime;
    static readonly Python27: InlinableRuntime;
    static readonly Python36: InlinableRuntime;
    static readonly DotNetCore1: Runtime;
    static readonly DotNetCore2: Runtime;
    static readonly DotNetCore21: Runtime;
    static readonly Go1x: Runtime;
    /** The name of this runtime, as expected by the Lambda resource. */
    readonly name: string;
    /** Whether the ``ZipFile`` (aka inline code) property can be used with this runtime. */
    readonly supportsInlineCode: boolean;
    constructor(name: string, props?: LambdaRuntimeProps);
    toString(): string;
}
/**
 * A ``LambdaRuntime`` that can be used in conjunction with the ``ZipFile``
 * property of the ``AWS::Lambda::Function`` resource.
 */
export interface InlinableRuntime {
    readonly name: string;
    readonly supportsInlineCode: boolean;
}
/**
 * A ``LambdaRuntime`` that can be used for inlining JavaScript.
 */
export interface InlinableJavaScriptRuntime extends InlinableRuntime {
}
